;                      Configure the MPE V/E system disc.
;
;
; This include file configures the MPE V/E system disc parameters.  It is
; invoked by the various MPE command files, as follows:
;
;    do configure-disc.inc <disc-model>
;
; ...where <disc-model> is one of the disc drive models supported by MPE V/E.
; These are:
;
;    Dev  Driver    Type  Subtype  Model
;    ---  --------  ----  -------  ----------------
;    DA   HIOMDSC1   0       8     7920 disc drive
;    DA   HIOMDSC1   0       9     7925 disc drive
;
;    DC   HIOMDSC2   3       1     7911 disc drive
;    DC   HIOMDSC2   3       2     7912 disc drive
;    DC   HIOMDSC2   3       4     7914 disc drive
;    DC   HIOMDSC2   3       8     7933 disc drive
;    DC   HIOMDSC2   3       8     7935 disc drive
;    DC   HIOMDSC2   3       9     7936 disc drive
;    DC   HIOMDSC2   3      10     7937 disc drive
;    DC   HIOMDSC2   3       5     7945 disc drive
;    DC   HIOMDSC2   3      13     7957B disc drive
;    DC   HIOMDSC2   3      14     7958B disc drive
;    DC   HIOMDSC2   3      15     7959B disc drive
;
; If the parameter is omitted, the 7914 disc model is used.  On return, the
; DEV, DRIVER, TYPE, SUBTYPE, MODEL, and VOLUME environment variables are set.
;
; This file is never invoked directly by the user.
;
;
; NOTES:
;
;  - The 7920 and 7925 models are not currently accepted as the DA device is not
;    yet implemented in the simulator.
;
;  - This command file sets both the MODEL and VOLUME environment variables.
;    The differentiation is required because INITIAL uses the MODEL (e.g.,
;    7959B) as the device name match from DEFDATA.PUB.SYS, but the volume name
;    is restricted to eight characters (e.g., MH7959U0).


; Verify that a correct disc type was supplied.

if "%1" == "" set env MODEL=7914
if "%1" != "" set env MODEL=%1

if "%MODEL%"     in "7920","7925" set env "DEV=DA","DRIVER=HIOMDSC1","TYPE=0"
if "%MODEL%" not in "7920","7925" set env "DEV=DC","DRIVER=HIOMDSC2","TYPE=3"

set env VOLUME=%MODEL%

if    "%MODEL%" in "7911","7912","7914","7933","7935","7936","7937","7945" goto %MODEL%
if -I "%MODEL%" in "7957B","7958B","7959B" goto %MODEL%

echo
echo The %MODEL% disc is not supported by MPE V/E.  Only the 7911, 7912, 7914,
echo 7933, 7935, 7936, 7937, 7945, 7957B, 7958B, and 7959B CS/80 disc models are
echo supported.
echo

exit


:7911
set env SUBTYPE=1
return


:7912
set env SUBTYPE=2
return


:7914
set env SUBTYPE=4
return


:7933
:7935
set env SUBTYPE=8
return


:7936
set env SUBTYPE=9
return


:7937
set env SUBTYPE=10
return


:7945
set env SUBTYPE=5
return


:7957b
:7957B
set env "MODEL=7957B","VOLUME=7957","SUBTYPE=13"
return


:7958b
:7958B
set env "MODEL=7958B","VOLUME=7958","SUBTYPE=14"
return


:7959b
:7959B
set env "MODEL=7959B","VOLUME=7959","SUBTYPE=15"
return
